@@ -2,16 +2,14 @@ package Pcore::Util::Perl;
 
 use Pcore;
 
-no Pcore;
+sub module {
+    state $init = !!require Pcore::Util::Perl::Module;
 
-sub module ( $self, @args ) {
-    require Pcore::Util::Perl::Module;
-
-    return Pcore::Util::Perl::Module->new(@args);
+    return Pcore::Util::Perl::Module->new(@_);
 }
 
-sub moo ( $self, @args ) {
-    require Pcore::Util::Perl::Moo;
+sub moo {
+    state $init = !!require Pcore::Util::Perl::Moo;
 
     return 'Pcore::Util::Perl::Moo';
 }
